@@ -128,13 +128,9 @@ class CodeReviewer:
         user: Optional[str] = None,
         reeval_response: bool = False,
         model="default",
-        custom_prompt="",
     ) -> ReviewOutput:
         prompt = CODE_REVIEW_PROMPT.format(
-            PULL_REQUEST_TITLE=pull_request_title,
-            PULL_REQUEST_DESC=pull_request_desc,
             CODE_DIFF=parser.patch_to_combined_chunks(diff_text),
-            CUSTOM_PROMPT=custom_prompt,
         )
         self.total_usage = {
             "prompt_tokens": 0,
@@ -155,7 +151,6 @@ class CodeReviewer:
                 pull_request_desc,
                 user,
                 reeval_response,
-                custom_prompt=custom_prompt,
             )
 
         reviews.extend(self.check_sensitive_files(pull_request_files))
@@ -201,13 +196,14 @@ class CodeReviewer:
         self.logger.debug("Processing based on files")
         reviews = []
         code_quality = None
-        for file_review, quality in self._process_files_generator(
+        file_chunks_generator = self._process_files_generator(
             pull_request_files,
             pull_request_title,
             pull_request_desc,
             user,
             reeval_response,
-        ):
+        )
+        for file_review, quality in file_chunks_generator:
             reviews.extend(file_review)
             if quality:
                 if code_quality and code_quality > quality:
@@ -226,7 +222,6 @@ class CodeReviewer:
     ) -> Generator[List[Dict], None, None]:
         combined_diff_data = ""
         available_tokens = self.provider.available_tokens(FILE_CODE_REVIEW_PROMPT)
-
         for file in pull_request_files:
             patch_details = file.get("patch")
             filename = file.get("filename", "").replace(" ", "")
@@ -274,8 +269,6 @@ class CodeReviewer:
         if not diff_data:
             return []
         prompt = FILE_CODE_REVIEW_PROMPT.format(
-            PULL_REQUEST_TITLE=pull_request_title,
-            PULL_REQUEST_DESC=pull_request_desc,
             FILE_PATCH=diff_data,
         )
         custom_model = {"model": self.default_model}
